The highest tagged major version is
v2.
package
Version:
v1.3.1
Opens a new window with list of versions in this module.
Published: Aug 15, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
UDP
server/gudp 中基于 G 包 UDP 组件实现了 Server,用以注册 udp 到 dove.Server() 中。
Documentation
¶
type ServerOption func(s *Server)
ServerOption 定义一个 UDP 服务选项类型。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.